@@ -1,55 +1,73 @@
 import os
-from dotenv import load_dotenv, find_dotenv
 from subprocess import Popen
 import mysql.connector
 import pandas as pd
 import psutil
 from flask import current_app
 from sqlalchemy import create_engine
-from .constants import  *
+
+import boto3
+import json
+
+try:
+    secret_name = "data-secret"
+    region_name = "ap-south-1"
+    session = boto3.session.Session()
+    client = session.client(
+        service_name='secretsmanager',
+        region_name=region_name
+    )
+
+    response = client.get_secret_value(
+        SecretId=secret_name
+    )
+    cred = json.loads(response['SecretString'])
+except:
+    print("you are not authorized to use Trell pip package")
+
 
 
 def insert_row_into_production_table(data, table_name):
-    conn = create_engine(os.getenv("ABHAY_DB_CONNECTION_STRING"))
+    conn = create_engine(cred['DATA_PROD_DB_CONNECTION_STRING'])
     try:
         data.to_sql(name=table_name, con=conn, if_exists='append', index=False)
     finally:
         conn.dispose()
 
 def insert_row_into_production_table_test(data, table_name):
-    conn = create_engine(os.getenv("TEST_DB_CONNECTION_STRING"))
+    conn = create_engine(cred['TEST_DB_CONNECTION_STRING'])
     try:
         data.to_sql(name=table_name, con=conn, if_exists='append', index=False)
     finally:
         conn.dispose()
 
 def update_production_data_table_row(query):
-    conn = create_engine(os.getenv("ABHAY_DB_CONNECTION_STRING"))
+    conn = create_engine(cred['DATA_PROD_DB_CONNECTION_STRING'])
     try:
         conn.execute(query)
     finally:
         conn.dispose()
 
 def create_table_in_prod_mysql(query):
-    conn = create_engine(os.getenv("ABHAY_DB_CONNECTION_STRING"))
+    conn = create_engine(cred['DATA_PROD_DB_CONNECTION_STRING'])
     try:
         conn.execute(query)
     finally:
         conn.dispose()
 
 def update_production_data_table_row_test(query):
-    conn = create_engine(os.getenv("TEST_DB_CONNECTION_STRING"))
+    conn = create_engine(cred['TEST_DB_CONNECTION_STRING'])
     try:
         conn.execute(query)
     finally:
         conn.dispose()
 
 def get_production_data_from_local(query, write_to_csv=False, filename="trail_loves.csv"):
-    cnx = mysql.connector.connect(user=os.getenv("ABHAY_USER"),
-                                  password=os.getenv("ABHAY_PWD"),
-                                  host=os.getenv("LOCAL_HOST"),
-                                  port=os.getenv("PORT_1"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host="127.0.0.1",
+                                  port=cred['PORT_1'],
+                                  database="trellDb")
     try:
         df = pd.read_sql(query + " ;", cnx)
         if write_to_csv:
@@ -60,40 +78,40 @@ def get_production_data_from_local(query, write_to_csv=False, filename="trail_lo
 
 
 def get_production_data_from_test(query):
-    cnx = mysql.connector.connect(user=os.getenv("TEST_USER"),
-                                  password=os.getenv("TEST_PWD"),
-                                  host=os.getenv("TEST_HOST"),
-                                  port=os.getenv("PORT_2"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['TEST_USER'],
+                                  password=cred['TEST_PWD'],
+                                  host=cred['TEST_HOST'],
+                                  port=cred['PORT_2'],
+                                  database="trellDb")
     try:
         return pd.read_sql(query + " ;", cnx)
     finally:
         cnx.close()
 
 def get_production_data_from_prod(query):
-    cnx = mysql.connector.connect(user=os.getenv("ABHAY_USER"),
-                                  password=os.getenv("ABHAY_PWD"),
-                                  host= os.getenv("PROD_HOST"),
-                                  port=os.getenv("PORT_2"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host= cred['PROD_HOST'],
+                                  port=cred['PORT_2'],
+                                  database="trellDb")
     try:
         return pd.read_sql(query + " ;", cnx)
     finally:
         cnx.close()
 
 def get_analytics_data(query):
-    cnx = mysql.connector.connect(user=os.getenv("RAHUL_USER"),
-                                  password=os.getenv("RAHUL_PWD"),
-                                  host=os.getenv("ANAL_HOST"),
-                                  port=os.getenv("PORT_2"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host=cred['ANAL_HOST'],
+                                  port=cred['PORT_2'],
+                                  database="trellDb")
     try:
         return pd.read_sql(query + " ;", cnx)
     finally:
         cnx.close()
 
 def write_into_analytics_table(data, table_name, db_name):
-    conn = create_engine(os.getenv("ABHAY_DB_CONNECTION_STRING_ANAL"))
+    conn = create_engine(cred['DATA_ANAL_DB_STRING'])
     try:
         print("Before to_sql")
         data.to_sql(name=table_name, schema=db_name, con=conn, if_exists='append', index=False)
@@ -105,7 +123,7 @@ def write_into_analytics_table(data, table_name, db_name):
         conn.dispose()
 
 def get_analytics_events_data(limit=1000, write_to_local = False, debug=False):
-    db_connection = create_engine(os.getenv("DIPO_DB_CONNECTION_STRING_ANAL"))
+    db_connection = create_engine(cred['DATA_ANAL_DB_STRING'])
     df = pd.read_sql('SELECT * FROM events LIMIT ' + str(limit), con=db_connection)
     if debug:
         print(df.head())
@@ -115,10 +133,10 @@ def get_analytics_events_data(limit=1000, write_to_local = False, debug=False):
 
 
 def get_production_data(table_name="content", limit=300, write_to_local=False, debug=False):
-    cnx = mysql.connector.connect(user=os.getenv("DIPO_USER"),
-                                  password=os.getenv("DIPO_PWD"),
-                                  host=os.getenv("PROD_HOST"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host=cred['PROD_HOST'],
+                                  database="trellDb")
     try:
         return pd.read_sql("SELECT * FROM " + str(table_name) + " LIMIT " + str(limit) + " ;", cnx)
     finally:
@@ -126,20 +144,20 @@ def get_production_data(table_name="content", limit=300, write_to_local=False, d
 
 
 def get_production_data_query(query, write_to_local=False, debug=False):
-    cnx = mysql.connector.connect(user=os.getenv("DIPO_USER"),
-                                  password=os.getenv("DIPO_PWD"),
-                                  host=os.getenv("PROD_HOST"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host=cred['PROD_HOST'],
+                                  database="trellDb")
     try:
         return pd.read_sql(query + " ;", cnx)
     finally:
         cnx.close()
 
 def delete_from_production_data_query(query):
-    cnx = mysql.connector.connect(user=os.getenv("DIPO_USER"),
-                                  password=os.getenv("DIPO_PWD"),
-                                  host=os.getenv("PROD_HOST"),
-                                  database=os.getenv("DATABASE_1"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host=cred['PROD_HOST'],
+                                  database="trellDb")
     mycursor = cnx.cursor(buffered=True)
     mycursor.execute(query)
     cnx.commit()
@@ -148,10 +166,10 @@ def delete_from_production_data_query(query):
     cnx.close()
 
 def delete_from_datascience_data_query(query):
-    cnx = mysql.connector.connect(user=os.getenv("DIPO_USER"),
-                                  password=os.getenv("DIPO_PWD"),
-                                  host=os.getenv("PROD_HOST"),
-                                  database=os.getenv("DATABASE_2"))
+    cnx = mysql.connector.connect(user=cred['DATA_USER'],
+                                  password=cred['DATA_PWD'],
+                                  host=cred['PROD_HOST'],
+                                  database="data_science")
     mycursor = cnx.cursor(buffered=True)
     mycursor.execute(query)
     cnx.commit()
@@ -166,7 +184,7 @@ def write_to_table(data, table_name):
     current_app.logger.info("Writing {} rows onto the Table \
         dailyUsers".format(data.shape[0]))
     current_app.logger.info(data.dtypes)
-    engine = create_engine(os.getenv("DB_CONNECTION_STRING_INTERN"), echo=False)
+    engine = create_engine(cred['DB_CONNECTION_STRING_INTERN'], echo=False)
     data.to_sql(name=table_name, con=engine, if_exists='append', index=False)
     current_app.logger.info("Data Successfully Written into {}".format(table_name))
 
