@@ -29,4 +29,10 @@ from .MysqlAdapter import (
     write_to_table,
     connect_to_database,
     check_process,
+)
+
+from .S3Adapter import (
+    read_from_s3_bucket,
+    write_to_s3_bucket,
+    upload_data_from_local_to_s3,
 )
\ No newline at end of file
